dnl Che
dnl currently needed only by ffmpeg
dnl AC_FUNC_LRINTF([ACTION-IF-FOUND-LRINTF [, ACTION-IF-NOT-FOUND-LRINTF]])
dnl
AC_DEFUN([AC_FUNC_LRINTF],
[
    AC_CACHE_CHECK([whether system declares lrintf function in math.h],
		   ac_cv_val_have_lrintf,
		   [ac_save_CFLAGS=$CFLAGS
		   ac_save_LIBS=$LIBS
                   CFLAGS="$CFLAGS -O2"
		   LIBS="$LIBS -lm"
                   AC_RUN_IFELSE(AC_LANG_SOURCE([
		    #define _ISOC9X_SOURCE  1
		    #include <math.h>
		    int main( void ) { return (lrintf(3.999f) > 0)?0:1; }]),
                    ac_cv_val_have_lrintf=yes, ac_cv_val_have_lrintf=no,
                    [ echo $ac_n "cross compiling; assumed OK... $ac_c" ])
                   CFLAGS=$ac_save_CFLAGS
                   LIBS=$ac_save_LIBS
		   ])
    if test "$ac_cv_val_have_lrintf" = yes; then
        ifelse([$1], , :, [$1])
    else
        ifelse([$2], , :, [$2])
    fi
])

dnl
dnl AC_CHECK_IPV6([ACTION-IF-FOUND-IPV6 [, ACTION-IF-NOT-FOUND-IPV6]])
dnl
AC_DEFUN([AC_CHECK_IPV6],
[
    AC_CACHE_CHECK([whether system supports IPv6],
		   ac_cv_val_have_ipv6,
		   AC_COMPILE_IFELSE(AC_LANG_PROGRAM([
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>
                   ], [
  struct sockaddr_storage saddr;
  struct ipv6_mreq mreq6;
  getaddrinfo(0,0,0,0);
  getnameinfo(0,0,0,0,0,0,0);
  IN6_IS_ADDR_MULTICAST((const struct in6_addr *)0);
                   ]), ac_cv_val_have_ipv6=yes, ac_cv_val_have_ipv6=no)
		   )
    if test "$ac_cv_val_have_ipv6" = yes; then
        ifelse([$1], , :, [$1])
    else
        ifelse([$2], , :, [$2])
    fi
])

dnl
dnl AC_CHECK_ALIGN_POWER([ACTION-IF-FOUND-ALIGN_POWER [, ACTION-IF-NOT-FOUND-ALIGN_POWER]])
dnl
AC_DEFUN([AC_CHECK_ALIGN_POWER],
[
    AC_CACHE_CHECK([whether .align arg is power-of-two],
		   ac_cv_val_have_align_power,
		   AC_COMPILE_IFELSE(AC_LANG_PROGRAM([],
                   [ asm (".align 3") ]),
                   ac_cv_val_have_align_power=yes, ac_cv_val_have_align_power=no)
		   )
    if test "$ac_cv_val_have_align_power" = yes; then
        ifelse([$1], , :, [$1])
    else
        ifelse([$2], , :, [$2])
    fi
])


dnl Usage:
dnl AM_PATH_FFMPEG([ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]])
dnl Test for ffmpeg, and define FFMPEG_CFLAGS and FFMPEG_LIBS

AC_DEFUN([AM_PATH_FFMPEG],
[
    AC_FUNC_LRINTF([    
	AC_DEFINE(HAVE_LRINTF, 1, [Define if you have lrintf on your system.])
        AC_DEFINE(_ISOC9X_SOURCE, 1, [Define for proper lrintf prototype.])])

    AC_CHECK_ALIGN_POWER([
        AC_DEFINE(ASMALIGN(ZEROBITS), [".align " #ZEROBITS "\n\t"], [ffmpeg Define if your .align arg is power-of-two.])],[
        AC_DEFINE(ASMALIGN(ZEROBITS), [".align 1<<" #ZEROBITS "\n\t"], [ffmpeg Define if your .align arg is not power-of-two.])])

    dnl !!! - it really sucks - Makefile.am can not be optimized even by
    dnl !!! preparing some extra variable forward
    dnl !!! FFAVFORMAT_SRC=

    AC_DEFINE(CONFIG_ENCODERS, 1, [ffmpeg Define if you want to build encoders.])
    AC_DEFINE(CONFIG_DECODERS, 1, [ffmpeg Define if you want to build decoders.])
    AC_DEFINE(CONFIG_MUXERS, 1, [ffmpeg Define if you want to build muxers.])
    AC_DEFINE(CONFIG_DEMUXERS, 1, [ffmpeg Define if you want to build demuxers.])

    AC_ARG_ENABLE(ffmpeg_a52, [  --disable-ffmpeg-a52    do not build ffmpeg with A52 (AC3) support. [[enabled]]],
		  [], enable_ffmpeg_a52=yes)
    if test "$enable_ffmpeg_a52" = yes; then
	AC_DEFINE(CONFIG_AC3_DECODER, 1, [ffmpeg Define if you want to use A52 audio decoder.])
	AC_ARG_ENABLE(ffmpeg_a52bin, [  --enable-ffmpeg-a52bin  A52 plugin dlopens liba52.so.0 at runtime [[disabled]]],
		      [], enable_ffmpeg_a52bin=no)

        if test "$enable_ffmpeg_a52bin" = yes; then
            AC_DEFINE(CONFIG_A52BIN, 1, [ffmpeg Define if you want to build with A52 dlopened decoder.])
        fi
    fi

    AC_REQUIRE([AM_PATH_DTS])
    AC_ARG_ENABLE(ffmpeg_dts, [  --disable-ffmpeg-dts    disable DTS support in ffmpeg. [[enabled]]],
                  [], enable_ffmpeg_dts=yes)
    if test "$enable_ffmpeg_dts" = yes -a "$have_dts" = yes; then
        AC_DEFINE(CONFIG_DTS, 1, [ffmpeg Define if you want to build with DTS.])
        AC_DEFINE(CONFIG_DTS_DEMUXER, 1, [ffmpeg Define if you want to build with DTS demuxer.])
        AC_DEFINE(CONFIG_DTS_DECODER, 1, [ffmpeg Define if you want to build with DTS decoder.])
    fi

    AC_ARG_ENABLE(ffmpeg_pp, [  --disable-ffmpeg-pp     disable postprocessing support in ffmpeg. [[enabled]]],
                  [], enable_ffmpeg_pp=yes)
    if test "$enable_ffmpeg_pp" = yes; then
        AC_DEFINE(CONFIG_PP, 1, [ffmpeg Define if you want to build with PP support.])
    fi

    AC_ARG_ENABLE(ffmpeg_swscaler, [  --enable-ffmpeg-swscaler build ffmpeg with SWScaler. [[disabled]]],
                  [], enable_ffmpeg_swscaler=no)
    if test "$enable_ffmpeg_swscaler" = yes; then
        AC_DEFINE(CONFIG_SWSCALER, 1, [ffmpeg Define if you want to build with SWScaler.])
    fi

    AC_ARG_ENABLE(ffmpeg_mpegaudiohp, [  --disable-ffmpeg-mpegaudiohp build ffmpeg with MPEG HighPrecision. [[enabled]]],
                  [], enable_ffmpeg_mpegaudiohp=yes)
    if test "$enable_ffmpeg_mpegaudiohp" = yes; then
        AC_DEFINE(CONFIG_MPEGAUDIO_HP, 1, [ffmpeg Define if you want to have highprecision mpeg audio support compiled.])
    fi

    AC_REQUIRE([AC_CHECK_V4L])
    if test "$enable_v4l" = yes; then
	AC_DEFINE(CONFIG_VIDEO4LINUX, 1, [ffmpeg Define if you have video4linux device.])
    fi
 
    AC_REQUIRE([AC_CHECK_V4L2])
    if test "$enable_v4l2" = yes; then
	AC_DEFINE(CONFIG_VIDEO4LINUX2, 1, [ffmpeg Define if you have video4linux2 device.])
    fi

    AC_ARG_ENABLE(ffmpeg_dv1394, [  --disable-ffmpeg-dv1394 disable ffmpeg DV1394 support. [[enabled]]],
                  [], enable_ffmpeg_dv1394=yes)
    if test "$enable_ffmpeg_dv1394" = yes; then
        AC_DEFINE(CONFIG_DV1394, 1, [ffmpeg Define if you want to have DV1394 support compiled.])
        AC_DEFINE(CONFIG_DV1394_DEMUXER, 1, [ffmpeg Define if you want to have DV1394 support compiled.])
    fi

    AC_ARG_ENABLE(ffmpeg_dc1394, [  --enable-ffmpeg-dc1394 ffmpeg DC1394 support. [[disabled]]],
                  [], enable_ffmpeg_dc1394=no)
    if test "$enable_ffmpeg_dc1394" = yes; then
        AM_PATH_DC1394([
            AC_DEFINE(CONFIG_DC1394, 1, [ffmpeg Define if you want to have DV1394 support compiled.])
            AC_DEFINE(CONFIG_DC1394_DEMUXER, 1, [ffmpeg Define if you want to have DV1394 demuxer.])
            ], [])
    fi

    AC_REQUIRE([AC_CHECK_OSS])
    if test "$enable_oss" = yes; then
	AC_DEFINE(CONFIG_AUDIO_OSS, 1, [ffmpeg Define if you want to have OSS audio support compiled.])
    fi

    AC_ARG_ENABLE(ffmpeg_network, [  --disable-ffmpeg-network disable network support. [[enabled]]],
                  [], enable_ffmpeg_network=yes)
    if test "$enable_ffmpeg_network" = yes; then
        AC_DEFINE(CONFIG_NETWORK, 1, [ffmpeg Define if you want to build with network support.])
    fi

    AC_CHECK_IPV6([
       if test "$enable_ffmpeg_network" = yes; then
            AC_DEFINE(CONFIG_IPV6, 1, [ffmpeg Define if you want to build with IPv6 support.])
       fi], [])

    AC_ARG_ENABLE(ffmpeg_protocol, [  --disable-ffmpeg-protocol disable ffmpeg protocol support. [[enabled]]],
                  [], enable_ffmpeg_protocol=yes)
    if test "$enable_ffmpeg_protocol" = yes; then
        AC_DEFINE(CONFIG_PROTOCOLS, 1, [ffmpeg Define if you want to build with protocols registered.])
    fi
    
    AC_REQUIRE([AC_FIND_ZLIB])
    if  test "$have_zlib" = yes; then
	AC_DEFINE(CONFIG_ZLIB, 1, [ffmpeg Define if you have z library (-lz)])
    fi

    AC_REQUIRE([AM_PATH_FAAD])
    if test "$have_faad" = yes; then
        AC_DEFINE(CONFIG_FAAD, 1, [ffmpeg Define if you want to have AAC support compiled.])
    fi

    AC_ARG_ENABLE(ffmpeg_faadbin, [  --disable-ffmpeg-faadbin do not build ffmpeg with FAAD bin.support. [[enabled]]],
	          [], enable_ffmpeg_faadbin=yes)
    if test "$enable_ffmpeg_faadbin" = yes; then
        AC_DEFINE(CONFIG_FAADBIN, 1, [ffmpeg Define if you want to build support for runtime linked libfaad.])
    fi

    AC_DEFINE(CONFIG_FFSERVER, 1, [ffmpeg Define if you want to build server.])

    AC_DEFINE(CONFIG_AC3, 1, [ffmpeg Define if you want to build AC3 decoder.])
    AC_DEFINE(SIMPLE_IDCT, 1, [ffmpeg Define if you want to build with simples idct.])
    AC_DEFINE(HAVE_PTHREADS, 1, [ffmpeg Define if you want to have pthread support compiled.])

    AC_DEFINE(CONFIG_GIF_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H263_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H261_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG4_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MSMPEG4V1_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MSMPEG4V2_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MSMPEG4V3_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WMV1_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WMV2_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VC1_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WMV3_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H263I_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FLV_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RV10_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RV20_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SVQ1_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SVQ3_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WMAV1_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WMAV2_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_INDEO2_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_INDEO3_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_TSCC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_CSCD_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_NUV_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ULTI_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_QDRAW_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_XL_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_QPEG_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_LOCO_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_KMVC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WNV1_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AASC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FRAPS_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AAC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG4AAC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG1VIDEO_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG2VIDEO_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEGVIDEO_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG_XVMC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DVVIDEO_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MJPEG_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MJPEGB_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SP5X_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PNG_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MP2_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MP3_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MP3ADU_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MP3ON4_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MACE3_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MACE6_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_HUFFYUV_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FFVHUFF_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FFV1_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_CYUV_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H264_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VP3_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_THEORA_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VP5_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VP6_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VP6F_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ASV1_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ASV2_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VCR1_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_CLJR_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FOURXM_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MDEC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ROQ_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_INTERPLAY_VIDEO_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_XAN_WC3_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RPZA_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_CINEPAK_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MSRLE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MSVIDEO1_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VQA_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_IDCIN_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_EIGHTBPS_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SMC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FLIC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_TRUEMOTION1_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_TRUEMOTION2_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VMDVIDEO_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VMDAUDIO_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MSZH_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ZLIB_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ZMBV_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SMACKER_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SMACKAUD_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SONIC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RA_144_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RA_288_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ROQ_DPCM_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_INTERPLAY_DPCM_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_XAN_DPCM_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SOL_DPCM_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_QTRLE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FLAC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SHORTEN_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ALAC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WS_SND1_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_QDM2_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_COOK_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_TRUESPEECH_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_TTA_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AVS_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_CAVS_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RAWVIDEO_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FLASHSV_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VMNC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WAVPACK_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_TARGA_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DSICINVIDEO_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DSICINAUDIO_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_TIERTEXSEQVIDEO_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_TIFF_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_IMC_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_BMP_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MMVIDEO_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S32LE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S32BE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U32LE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U32BE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S24LE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S24BE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U24LE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U24BE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S24DAUD_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S16LE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S16BE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U16LE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U16BE_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S8_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U8_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_ALAW_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_MULAW_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_IMA_QT_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_IMA_WAV_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_IMA_DK3_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_IMA_DK4_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_IMA_WS_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_IMA_SMJPEG_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_MS_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_4XM_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_XA_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_ADX_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_EA_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_G726_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_CT_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_SWF_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_YAMAHA_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_SBPRO_4_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_SBPRO_3_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_SBPRO_2_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DVDSUB_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DVBSUB_DECODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FOURXM_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AIFF_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AMR_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ASF_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AU_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AUDIO_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AVI_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AVISYNTH_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AVS_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DAUD_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DSICIN_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DV1394_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DV_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_EA_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FFM_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FLIC_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FLV_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_GIF_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_GXF_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_IDCIN_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ROQ_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_IMAGE2_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_IMAGE2PIPE_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_IPMOVIE_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MATROSKA_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MM_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MMF_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MOV_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MTV_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MP3_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEGPS_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEGTS_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MXF_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_NSV_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_NUT_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_NUV_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_STR_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SHORTEN_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FLAC_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AC3_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DTS_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AAC_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H261_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H263_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_M4V_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H264_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEGVIDEO_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MJPEG_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_INGENIENT_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S16LE_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S16BE_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U16LE_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U16BE_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S8_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U8_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_MULAW_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_ALAW_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RAWVIDEO_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RM_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RTSP_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SDP_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_REDIR_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SEGAFILM_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VMD_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SMACKER_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SOL_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SWF_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_TTA_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_V4L2_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VIDEO_GRAB_DEVICE_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VOC_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WAV_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WC3_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WSAUD_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WSVQA_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WV_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_YUV4MPEGPIPE_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_TIERTEXSEQ_DEMUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AC3_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MP2_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FLAC_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_GIF_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG1VIDEO_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H264_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG2VIDEO_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H261_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H263_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H263P_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FLV_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RV10_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RV20_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG4_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MSMPEG4V1_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MSMPEG4V2_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MSMPEG4V3_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WMV1_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WMV2_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SVQ1_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MJPEG_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_LJPEG_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_JPEGLS_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PNG_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PPM_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PGM_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PGMYUV_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PBM_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PAM_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_HUFFYUV_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FFVHUFF_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ASV1_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ASV2_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FFV1_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ZLIB_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DVVIDEO_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SONIC_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SONIC_LS_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_X264_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RAWVIDEO_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S32LE_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S32BE_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U32LE_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U32BE_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S24LE_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S24BE_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U24LE_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U24BE_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S24DAUD_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S16LE_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S16BE_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U16LE_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U16BE_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S8_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U8_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_ALAW_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_MULAW_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_IMA_QT_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_IMA_WAV_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_IMA_DK3_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_IMA_DK4_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_IMA_WS_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_IMA_SMJPEG_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_MS_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_4XM_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_XA_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_ADX_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_EA_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_G726_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_CT_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_SWF_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_YAMAHA_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_SBPRO_4_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_SBPRO_3_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADPCM_SBPRO_2_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DVDSUB_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DVBSUB_ENCODER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ADTS_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AIFF_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AMR_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ASF_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_ASF_STREAM_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AU_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AUDIO_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AVI_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_CRC_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FRAMECRC_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DV_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FFM_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FLV_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_GIF_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_GXF_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_IMAGE2_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_IMAGE2PIPE_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MMF_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MOV_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_TGP_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MP4_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PSP_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_TG2_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MP2_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MP3_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG1SYSTEM_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG1VCD_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG2VOB_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG2SVCD_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG2DVD_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEGTS_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPJPEG_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_NUT_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_FLAC_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AC3_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H261_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H263_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_M4V_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H264_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG1VIDEO_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG2VIDEO_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MJPEG_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S16LE_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S16BE_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U16LE_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U16BE_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_S8_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_U8_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_MULAW_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PCM_ALAW_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RAWVIDEO_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_NULL_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RM_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_RTP_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_SWF_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_VOC_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_WAV_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_YUV4MPEGPIPE_MUXER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEGVIDEO_PARSER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEG4VIDEO_PARSER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_CAVSVIDEO_PARSER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H261_PARSER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H263_PARSER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_H264_PARSER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MJPEG_PARSER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_PNM_PARSER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_MPEGAUDIO_PARSER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AC3_PARSER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DVDSUB_PARSER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_DVBSUB_PARSER, 1, [ffmpeg])
    AC_DEFINE(CONFIG_AAC_PARSER, 1, [ffmpeg])

    if test -n "$ffmpeg_profiling" ; then
	AC_DEFINE(HAVE_GPROF, 1, [ffmpeg Define if you want to build with gprof support.])
    fi

    test -z "$FFMPEG_CFLAGS" && FFMPEG_CFLAGS="-O4 $DEFAULT_FLAGS"
    FFMPEG_CFLAGS="$FFMPEG_CFLAGS $DEFAULT_DEFINES"

    AC_CHECK_GNU_VECTOR(FFMPEG_SSE="-msse";
		        AC_DEFINE(HAVE_BUILTIN_VECTOR, 1, [ffmpeg Define if your compiler supports vector builtins (MMX).]), [])
    AC_SUBST(FFMPEG_CFLAGS)
    AC_SUBST(FFMPEG_SSE)

dnl ffmpeg_x86opt=
dnl test x$enable_x86opt = xno && ffmpeg_x86opt="--disable-mmx"
dnl AC_MSG_RESULT([=== configuring ffmpeg ===])
dnl    ( cd $srcdir/ffmpeg ; \
dnl      ./configure --prefix=$prefix --cc=$CC \
dnl		$ffmpeg_profiling $ffmpeg_cpu \
dnl		$ffmpeg_x86opt --disable-mp3lib \
dnl		--enable-simple_idct )
])
